@@ -6,7 +6,7 @@ class PasswordChangeFormMixin:
     def save(self, commit=True):
         old_password = self.cleaned_data["old_password"]
         new_password = self.cleaned_data["new_password1"]
-        if self.user.pgp_identity:
+        if hasattr(self.user, 'pgp_identity') and self.user.pgp_identity:
             self.user.pgp_identity.change_password(old_password, new_password)
         super().save(commit)
 
@@ -14,7 +14,7 @@ class PasswordChangeFormMixin:
 class PasswordResetFormMixin:
     def save(self, commit=True):
         new_password = self.cleaned_data["new_password1"]
-        if self.user.pgp_identity:
+        if hasattr(self.user, 'pgp_identity') and self.user.pgp_identity:
             self.user.pgp_identity.reset_password(new_password)
         super().save(commit)
 
